@@ -482,8 +482,9 @@ void gcpCurvedArrowTool::OnRelease ()
 	if (m_SetEnd)
 		a->SetEndAtNewBondCenter (m_EndAtBondCenter);
 	m_pView->Update (a);
-	
-	op->AddObject (obj, 1);
+
+	gcu::Object *group = obj->GetGroup ();
+	op->AddObject ((group)? group: obj, 1);
 	pDoc->FinishOperation ();
 }
 
@@ -1114,7 +1115,6 @@ void gcpCurvedArrowTool::ElectronToAdjBond ()
 
 void gcpCurvedArrowTool::ElectronToAtom ()
 {
-puts("electron to atom");
 	double x0 = 0., y0 = 0., x1 = 0., y1 = 0., x2 = 0., y2 = 0., x3 = 0., y3 = 0., x, y, a, dx, dy, l;
 	gcp::Electron *elec = static_cast <gcp::Electron *> (m_pObject);
 	gcp::Atom *start = static_cast <gcp::Atom *> (elec->GetParent ()),
