@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-curve.h 
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -29,13 +29,6 @@
 #include <gcu/printable.h>
 #include <string>
 #include "gchemtable-app.h"
-#ifdef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/goffice.h>
-#else
-#   include <goffice/graph/gog-graph.h>
-#endif
-#include <gtk/gtkpagesetup.h>
-#include <gtk/gtkprintsettings.h>
 
 using namespace gcu;
 
@@ -52,16 +45,19 @@ public:
 	void OnClose ();
 	void OnProperties ();
 
-	void DoPrint (GtkPrintOperation *print, GtkPrintContext *context) const;
+	void DoPrint (GtkPrintOperation *print, GtkPrintContext *context, int page) const;
 	void SetGraph (GogGraph *graph);
 	GtkWindow *GetGtkWindow () {return GTK_WINDOW (dialog);}
 	void ClearGuru () {m_Guru = NULL;}
 	void SaveAsImage (std::string const &filename, char const *mime_type, unsigned width, unsigned height) const;
+	static void OnSize (GChemTableCurve *curve, GtkAllocation *allocation);
+	static bool OnMotion (GChemTableCurve *curve, GdkEventMotion *event);
 
 private:
 	std::string m_Name;
 	GogGraph *m_Graph;
 	GtkWidget *m_GraphWidget, *m_GraphBox, *m_Guru;
+	int m_GraphWidth, m_GraphHeight;
 };
 
 #endif	// GCHEMTABLE_CURVE_H
